@@ -1,5 +1,6 @@
 import threading
 from .LogLevel import LogLevel
+from iupdatable.system.io.Directory import Directory
 import logging as sys_logging
 import logging.handlers
 import datetime
@@ -94,7 +95,7 @@ class Logger(object):
         :return: 返回一个配置完成的logger
         """
         if log_file_full_path == "all.log" or len(log_file_full_path.strip()) == 0:
-            log_file_full_path = "all.log"
+            log_file_full_path = Directory.get_current_directory() + "/all.log"
 
         logger = sys_logging.getLogger(logger_name)
         logger.handlers.clear()  # 清空handlers，防止是二次调用config
